==> progamification-1.7.0.tar.gz: lib/src/widgets/billing_form.dart <==
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:progamification/src/services/redeem.service.dart';
import 'package:progamification/src/widgets/failure_redeem.dart';
import 'package:progamification/src/widgets/success_redeem.dart';
import 'package:progamification/src/widgets/wallet_balance.dart';

class BillingForm extends StatefulWidget {
  final String userId;
  final String applicationId;
  final productId;

  const BillingForm(
      {Key? key,
      required this.userId,
      required this.applicationId,
      required this.productId})
      : super(key: key);
  @override
  _BillingFormState createState() => _BillingFormState();
}

class _BillingFormState extends State<BillingForm> {
  final _formKey = GlobalKey<FormState>();
  late TextEditingController _nameController;
  late TextEditingController _contactNumberController;
  late TextEditingController _emailController;

  @override
  void initState() {
    super.initState();
    _nameController = TextEditingController();
    _contactNumberController = TextEditingController();
    _emailController = TextEditingController();
  }

  @override
  void dispose() {
    _nameController.dispose();
    _contactNumberController.dispose();
    _emailController.dispose();
    super.dispose();
  }

  Future<void> _submitForm() async {
    if (_formKey.currentState!.validate()) {
      Map<String, dynamic> product = {
        'email': _emailController.text,
        'firstName': _nameController.text,
        'gamificationApplicationId': widget.applicationId,
        'gamificationUserId': widget.userId,
        'redeemRuleId': widget.productId,
        'telephone': _contactNumberController.text,
      };
      try {
        final data = await Get.find<RedeemService>().redeemProduct(product);
        if (data.data['message'] == null) {
          print("Navigating to SuccessRedeem");
          Navigator.push(
            context,
            MaterialPageRoute(
              builder: (context) => SuccessRedeem(
                userId: widget.userId,
                applicationId: widget.applicationId,
                productId: widget.productId,
              ),
            ),
          );
        } else {
          print("Navigating to FailureRedeem");
          Navigator.push(
            context,
            MaterialPageRoute(
              builder: (context) => FailureRedeem(
                userId: widget.userId,
                applicationId: widget.applicationId,
                productId: widget.productId,
              ),
            ),
          );
        }
      } catch (e) {
        print("Error during redemption: $e");
      }
    }
    _formKey.currentState!.reset();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Colors.white,
      appBar: AppBar(
        backgroundColor: Colors.white,
        automaticallyImplyLeading: false,
        toolbarHeight: kTextTabBarHeight, //kToolbarHeight,
        flexibleSpace: Get.width < 600
            ? Row(
                mainAxisAlignment: MainAxisAlignment.start,
                crossAxisAlignment: CrossAxisAlignment.center,
                children: [
                  Container(
                    decoration: BoxDecoration(
                      borderRadius: BorderRadius.circular(50),
                      border: Border.all(color: Colors.grey[400]!),
                    ),
                    margin: const EdgeInsets.only(top: 45.0, left: 20),
                    child: ClipRRect(
                      borderRadius: BorderRadius.circular(30),
                      child: FloatingActionButton(
                        onPressed: (() => Navigator.pop(context)),
                        elevation: 0,
                        backgroundColor: Colors.grey[100],
                        child: const Icon(
                          Icons.arrow_back,
                          color: Colors.black,
                        ),
                      ),
                    ),
                  ),
                  Container(
                      margin: const EdgeInsets.only(top: 45.0, left: 20),
                      child: Text(
                        "Billing Address",
                        style: TextStyle(
                            fontSize: 25, fontWeight: FontWeight.bold),
                      )),
                  Spacer(),
                  Padding(
                    padding: const EdgeInsets.only(right: 20.0),
                    child: WalletBalance(
                      userId: widget.userId,
                      applicationId: widget.applicationId,
                    ),
                  ),
                ],
              )
            : null,
      ),
      body: SafeArea(
        child: Column(
          children: [
            Padding(
              padding: const EdgeInsets.all(18.0),
              child: Form(
                key: _formKey,
                child: Column(
                  crossAxisAlignment: CrossAxisAlignment.stretch,
                  children: [
                    _buildLabel("Name"),
                    SizedBox(height: 10),
                    _buildTextField(_nameController),
                    SizedBox(height: 20),
                    _buildLabel("Contact Number"),
                    SizedBox(height: 10),
                    _buildTextField(_contactNumberController),
                    SizedBox(height: 20),
                    _buildLabel("Email"),
                    SizedBox(height: 10),
                    _buildTextField(_emailController),
                    SizedBox(height: 20),
                    ElevatedButton(
                      style: ButtonStyle(
                        backgroundColor:
                            MaterialStateProperty.all<Color>(Color(0xFFF5DA48)),
                      ),
                      onPressed: _submitForm,
                      child: Text(
                        'Redeem Now >',
                        style: TextStyle(color: Colors.black),
                      ),
                    ),
                  ],
                ),
              ),
            ),
          ],
        ),
      ),
    );
  }

  Widget _buildLabel(String labelText) {
    return Row(
      children: [
        Text(
          labelText,
          style: TextStyle(
            fontSize: 17,
            fontWeight: FontWeight.bold,
          ),
        ),
        Text(
          ' *',
          style: TextStyle(
            color: Colors.red,
          ),
        ),
      ],
    );
  }

  Widget _buildTextField(TextEditingController controller) {
    return TextFormField(
      controller: controller,
      onChanged: (_) {
        _formKey.currentState!.validate();
      },
      validator: (value) {
        if (value == null || value.isEmpty) {
          return 'Please enter ${controller == _nameController ? 'your name' : controller == _contactNumberController ? 'your contact number' : 'your email'}';
        }
        if (controller == _contactNumberController) {
          if (value.length != 10) {
            return 'Please enter a 10-digit contact number';
          }
        } else if (controller == _emailController) {
          bool isValidEmail =
              RegExp(r'^[\w-\.]+@([\w-]+\.)+[\w-]{2,4}$').hasMatch(value);
          if (!isValidEmail) {
            return 'Please enter a valid email address';
          }
        }
        return null;
      },
      decoration: InputDecoration(
        border: OutlineInputBorder(),
        contentPadding: EdgeInsets.symmetric(vertical: 14.0, horizontal: 10.0),
        // hintText:
        //     'Please enter ${controller == _nameController ? 'your name' : controller == _contactNumberController ? 'your contact number' : 'your email'}'
      ),
    );
  }
}

==> progamification-1.7.1.tar.gz: lib/src/widgets/billing_form.dart <==
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:progamification/src/services/redeem.service.dart';
import 'package:progamification/src/widgets/failure_redeem.dart';
import 'package:progamification/src/widgets/success_redeem.dart';
import 'package:progamification/src/widgets/wallet_balance.dart';

class BillingForm extends StatefulWidget {
  final String userId;
  final String applicationId;
  final productId;

  const BillingForm(
      {Key? key,
      required this.userId,
      required this.applicationId,
      required this.productId})
      : super(key: key);
  @override
  _BillingFormState createState() => _BillingFormState();
}

class _BillingFormState extends State<BillingForm> {
  final _formKey = GlobalKey<FormState>();
  late TextEditingController _nameController;
  late TextEditingController _contactNumberController;
  late TextEditingController _emailController;

  @override
  void initState() {
    super.initState();
    _nameController = TextEditingController();
    _contactNumberController = TextEditingController();
    _emailController = TextEditingController();
  }

  @override
  void dispose() {
    _nameController.dispose();
    _contactNumberController.dispose();
    _emailController.dispose();
    super.dispose();
  }

  Future<void> _submitForm() async {
    if (_formKey.currentState!.validate()) {
      Map<String, dynamic> product = {
        'email': _emailController.text,
        'firstName': _nameController.text,
        'gamificationApplicationId': widget.applicationId,
        'gamificationUserId': widget.userId,
        'redeemRuleId': widget.productId,
        'telephone': '+91' + _contactNumberController.text,
      };
      try {
        final data = await Get.find<RedeemService>().redeemProduct(product);
        if (data.data['message'] == null) {
          print("Navigating to SuccessRedeem");
          Navigator.push(
            context,
            MaterialPageRoute(
              builder: (context) => SuccessRedeem(
                userId: widget.userId,
                applicationId: widget.applicationId,
                productId: widget.productId,
              ),
            ),
          );
        } else {
          print("Navigating to FailureRedeem");
          Navigator.push(
            context,
            MaterialPageRoute(
              builder: (context) => FailureRedeem(
                userId: widget.userId,
                applicationId: widget.applicationId,
                productId: widget.productId,
              ),
            ),
          );
        }
      } catch (e) {
        print("Error during redemption: $e");
      }
    }
    _formKey.currentState!.reset();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Colors.white,
      appBar: AppBar(
        backgroundColor: Colors.white,
        automaticallyImplyLeading: false,
        toolbarHeight: kTextTabBarHeight, //kToolbarHeight,
        flexibleSpace: Get.width < 600
            ? Row(
                mainAxisAlignment: MainAxisAlignment.start,
                crossAxisAlignment: CrossAxisAlignment.center,
                children: [
                  Container(
                    decoration: BoxDecoration(
                      borderRadius: BorderRadius.circular(50),
                      border: Border.all(color: Colors.grey[400]!),
                    ),
                    margin: const EdgeInsets.only(top: 45.0, left: 20),
                    child: ClipRRect(
                      borderRadius: BorderRadius.circular(30),
                      child: FloatingActionButton(
                        onPressed: (() => Navigator.pop(context)),
                        elevation: 0,
                        backgroundColor: Colors.grey[100],
                        child: const Icon(
                          Icons.arrow_back,
                          color: Colors.black,
                        ),
                      ),
                    ),
                  ),
                  Container(
                      margin: const EdgeInsets.only(top: 45.0, left: 20),
                      child: Text(
                        "Billing Address",
                        style: TextStyle(
                            fontSize: 25, fontWeight: FontWeight.bold),
                      )),
                  Spacer(),
                  Padding(
                    padding: const EdgeInsets.only(right: 20.0),
                    child: WalletBalance(
                      userId: widget.userId,
                      applicationId: widget.applicationId,
                    ),
                  ),
                ],
              )
            : null,
      ),
      body: SafeArea(
        child: Column(
          children: [
            Padding(
              padding: const EdgeInsets.all(18.0),
              child: Form(
                key: _formKey,
                child: Column(
                  crossAxisAlignment: CrossAxisAlignment.stretch,
                  children: [
                    _buildLabel("Name"),
                    SizedBox(height: 10),
                    _buildTextField(_nameController),
                    SizedBox(height: 20),
                    _buildLabel("Contact Number"),
                    SizedBox(height: 10),
                    _buildTextField(_contactNumberController),
                    SizedBox(height: 20),
                    _buildLabel("Email"),
                    SizedBox(height: 10),
                    _buildTextField(_emailController),
                    SizedBox(height: 20),
                    ElevatedButton(
                      style: ButtonStyle(
                        backgroundColor:
                            MaterialStateProperty.all<Color>(Color(0xFFF5DA48)),
                      ),
                      onPressed: _submitForm,
                      child: Text(
                        'Redeem Now >',
                        style: TextStyle(color: Colors.black),
                      ),
                    ),
                  ],
                ),
              ),
            ),
          ],
        ),
      ),
    );
  }

  Widget _buildLabel(String labelText) {
    return Row(
      children: [
        Text(
          labelText,
          style: TextStyle(
            fontSize: 17,
            fontWeight: FontWeight.bold,
          ),
        ),
        Text(
          ' *',
          style: TextStyle(
            color: Colors.red,
          ),
        ),
      ],
    );
  }

  Widget _buildTextField(TextEditingController controller) {
    return TextFormField(
      controller: controller,
      onChanged: (_) {
        _formKey.currentState!.validate();
      },
      validator: (value) {
        if (value == null || value.isEmpty) {
          return 'Please enter ${controller == _nameController ? 'your name' : controller == _contactNumberController ? 'your contact number' : 'your email'}';
        }
        if (controller == _contactNumberController) {
          if (value.length != 10) {
            return 'Please enter a 10-digit contact number';
          }
        } else if (controller == _emailController) {
          bool isValidEmail =
              RegExp(r'^[\w-\.]+@([\w-]+\.)+[\w-]{2,4}$').hasMatch(value);
          if (!isValidEmail) {
            return 'Please enter a valid email address';
          }
        }
        return null;
      },
      decoration: InputDecoration(
        border: OutlineInputBorder(),
        contentPadding: EdgeInsets.symmetric(vertical: 14.0, horizontal: 10.0),
        // hintText:
        //     'Please enter ${controller == _nameController ? 'your name' : controller == _contactNumberController ? 'your contact number' : 'your email'}'
      ),
    );
  }
}
